aboutsummaryrefslogtreecommitdiff
path: root/libstore/set.c
diff options
context:
space:
mode:
authorMiles Bader <miles@gnu.org>1996-05-10 17:32:33 +0000
committerMiles Bader <miles@gnu.org>1996-05-10 17:32:33 +0000
commit3a599ed5d204df4a0262d555ae7f46adcdf65bfc (patch)
tree04df0a24fa6a0da850037f9e0120bc298db8d3cf /libstore/set.c
parent48dee4ea42de87705260fb149e6ac223ca333ba8 (diff)
downloadhurd-3a599ed5d204df4a0262d555ae7f46adcdf65bfc.tar.gz
hurd-3a599ed5d204df4a0262d555ae7f46adcdf65bfc.tar.bz2
hurd-3a599ed5d204df4a0262d555ae7f46adcdf65bfc.zip
Rename *S_LEN to NUM_*S.
Diffstat (limited to 'libstore/set.c')
-rw-r--r--libstore/set.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/libstore/set.c b/libstore/set.c
index 60701f64..d59538e1 100644
--- a/libstore/set.c
+++ b/libstore/set.c
@@ -25,11 +25,11 @@
#include "store.h"
/* Set STORE's current runs list to (a copy of) RUNS and RUNS_LEN. */
error_t
-store_set_runs (struct store *store, const off_t *runs, unsigned runs_len)
+store_set_runs (struct store *store, const off_t *runs, unsigned num_runs)
{
- unsigned size = runs_len * sizeof (off_t);
+ unsigned size = num_runs * sizeof (off_t);
off_t *copy = malloc (size);
if (!copy)
@@ -40,7 +40,7 @@ store_set_runs (struct store *store, const off_t *runs, unsigned runs_len)
bcopy (runs, copy, size);
store->runs = copy;
- store->runs_len = runs_len;
+ store->num_runs = num_runs;
if (store->block_size > 0)
_store_derive (store);
@@ -25,11 +25,11 @@
#include "store.h"
-/* Set STORE's current runs list to (a copy of) RUNS and RUNS_LEN. */
+/* Set STORE's current runs list to (a copy of) RUNS and NUM_RUNS. */
error_t